==> haskell-cryptohash-conduit-0.1.1-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cryptohash-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-dec777bba26b4960028433a6d8dd1c26
key: crypt_7CEKgprLIcLE81SQPZ0PwA
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-7CEKgprLIcLE81SQPZ0PwA
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
    conduit-extra-1.1.9.2-aa4a80a63306500e6d6a1edce4badfdd
    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-13-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cryptohash-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-d1e5ead421e83b382920526806f6c034
key: crypt_A5mHXAJY1yPKrnjSRdvu40
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-A5mHXAJY1yPKrnjSRdvu40
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
